from distutils.core import setup
setup(
    name = 'cindy_test',
    version = '1.0.0',
    py_modules = ['cindy_test'],
    author = 'cindy',
    author_email = 'zhengping.pin@gmail.com',
    description = 'A simple printer of nested list',
    )
